@@ -1,4 +1,6 @@
-"""The Apple Framework builds require their own customization"""
+"""The Apple Framework builds require their own customization."""
+from __future__ import annotations
+
 import logging
 import os
 import struct
@@ -7,11 +9,14 @@ from abc import ABCMeta, abstractmethod
 from pathlib import Path
 from textwrap import dedent
 
-from virtualenv.create.via_global_ref.builtin.ref import ExePathRefToDest, PathRefToDest, RefMust
-from virtualenv.info import IS_MAC_ARM64
+from virtualenv.create.via_global_ref.builtin.ref import (
+    ExePathRefToDest,
+    PathRefToDest,
+    RefMust,
+)
+from virtualenv.create.via_global_ref.builtin.via_global_self_do import BuiltinViaGlobalRefMeta
 
-from .common import CPython, CPythonPosix, is_mac_os_framework
-from .cpython2 import CPython2PosixBase
+from .common import CPython, CPythonPosix, is_mac_os_framework, is_macos_brew
 from .cpython3 import CPython3
 
 
@@ -27,13 +32,12 @@ class CPythonmacOsFramework(CPython, metaclass=ABCMeta):
         target = self.desired_mach_o_image_path()
         current = self.current_mach_o_image_path()
         for src in self._sources:
-            if isinstance(src, ExePathRefToDest):
-                if src.must == RefMust.COPY or not self.symlinks:
-                    exes = [self.bin_dir / src.base]
-                    if not self.symlinks:
-                        exes.extend(self.bin_dir / a for a in src.aliases)
-                    for exe in exes:
-                        fix_mach_o(str(exe), current, target, self.interpreter.max_size)
+            if isinstance(src, ExePathRefToDest) and (src.must == RefMust.COPY or not self.symlinks):
+                exes = [self.bin_dir / src.base]
+                if not self.symlinks:
+                    exes.extend(self.bin_dir / a for a in src.aliases)
+                for exe in exes:
+                    fix_mach_o(str(exe), current, target, self.interpreter.max_size)
 
     @classmethod
     def _executables(cls, interpreter):
@@ -53,89 +57,6 @@ class CPythonmacOsFramework(CPython, metaclass=ABCMeta):
         raise NotImplementedError
 
 
-class CPython2macOsFramework(CPythonmacOsFramework, CPython2PosixBase):
-    @classmethod
-    def can_create(cls, interpreter):
-        if not IS_MAC_ARM64 and super().can_describe(interpreter):
-            return super().can_create(interpreter)
-        return False
-
-    def current_mach_o_image_path(self):
-        return os.path.join(self.interpreter.prefix, "Python")
-
-    def desired_mach_o_image_path(self):
-        return "@executable_path/../Python"
-
-    @classmethod
-    def sources(cls, interpreter):
-        yield from super().sources(interpreter)
-        # landmark for exec_prefix
-        exec_marker_file, to_path, _ = cls.from_stdlib(cls.mappings(interpreter), "lib-dynload")
-        yield PathRefToDest(exec_marker_file, dest=to_path)
-
-        # add a copy of the host python image
-        exe = Path(interpreter.prefix) / "Python"
-        yield PathRefToDest(exe, dest=lambda self, _: self.dest / "Python", must=RefMust.COPY)
-
-        # add a symlink to the Resources dir
-        resources = Path(interpreter.prefix) / "Resources"
-        yield PathRefToDest(resources, dest=lambda self, _: self.dest / "Resources")
-
-    @property
-    def reload_code(self):
-        result = super().reload_code
-        result = dedent(
-            f"""
-        # the bundled site.py always adds the global site package if we're on python framework build, escape this
-        import sysconfig
-        config = sysconfig.get_config_vars()
-        before = config["PYTHONFRAMEWORK"]
-        try:
-            config["PYTHONFRAMEWORK"] = ""
-            {result}
-        finally:
-            config["PYTHONFRAMEWORK"] = before
-        """,
-        )
-        return result
-
-
-class CPython2macOsArmFramework(CPython2macOsFramework, CPythonmacOsFramework, CPython2PosixBase):
-    @classmethod
-    def can_create(cls, interpreter):
-        if IS_MAC_ARM64 and super(CPythonmacOsFramework, cls).can_describe(interpreter):
-            return super(CPythonmacOsFramework, cls).can_create(interpreter)
-        return False
-
-    def create(self):
-        super(CPython2macOsFramework, self).create()
-        self.fix_signature()
-
-    def fix_signature(self):
-        """
-        On Apple M1 machines (arm64 chips),  rewriting the python executable invalidates its signature.
-        In python2 this results in a unusable python exe which just dies.
-        As a temporary workaround we can codesign the python exe during the creation process.
-        """
-        exe = self.exe
-        try:
-            logging.debug("Changing signature of copied python exe %s", exe)
-            bak_dir = exe.parent / "bk"
-            # Reset the signing on Darwin since the exe has been modified.
-            # Note codesign fails on the original exe, it needs to be copied and moved back.
-            bak_dir.mkdir(parents=True, exist_ok=True)
-            subprocess.check_call(["cp", str(exe), str(bak_dir)])
-            subprocess.check_call(["mv", str(bak_dir / exe.name), str(exe)])
-            bak_dir.rmdir()
-            metadata = "--preserve-metadata=identifier,entitlements,flags,runtime"
-            cmd = ["codesign", "-s", "-", metadata, "-f", str(exe)]
-            logging.debug("Changing Signature: %s", cmd)
-            subprocess.check_call(cmd)
-        except Exception:
-            logging.fatal("Could not change MacOS code signing on copied python exe at %s", exe)
-            raise
-
-
 class CPython3macOsFramework(CPythonmacOsFramework, CPython3, CPythonPosix):
     def current_mach_o_image_path(self):
         return "@executable_path/../../../../Python3"
@@ -154,7 +75,7 @@ class CPython3macOsFramework(CPythonmacOsFramework, CPython3, CPythonPosix):
     @property
     def reload_code(self):
         result = super().reload_code
-        result = dedent(
+        return dedent(
             f"""
         # the bundled site.py always adds the global site package if we're on python framework build, escape this
         import sys
@@ -166,12 +87,11 @@ class CPython3macOsFramework(CPythonmacOsFramework, CPython3, CPythonPosix):
             sys._framework = before
         """,
         )
-        return result
 
 
 def fix_mach_o(exe, current, new, max_size):
     """
-    https://en.wikipedia.org/wiki/Mach-O
+    https://en.wikipedia.org/wiki/Mach-O.
 
     Mach-O, short for Mach object file format, is a file format for executables, object code, shared libraries,
     dynamically-loaded code, and core dumps. A replacement for the a.out format, Mach-O offers more extensibility and
@@ -196,39 +116,39 @@ def fix_mach_o(exe, current, new, max_size):
     try:
         logging.debug("change Mach-O for %s from %s to %s", exe, current, new)
         _builtin_change_mach_o(max_size)(exe, current, new)
-    except Exception as e:
-        logging.warning("Could not call _builtin_change_mac_o: %s. " "Trying to call install_name_tool instead.", e)
+    except Exception as e:  # noqa: BLE001
+        logging.warning("Could not call _builtin_change_mac_o: %s. Trying to call install_name_tool instead.", e)
         try:
             cmd = ["install_name_tool", "-change", current, new, exe]
-            subprocess.check_call(cmd)
+            subprocess.check_call(cmd)  # noqa: S603
         except Exception:
-            logging.fatal("Could not call install_name_tool -- you must " "have Apple's development tools installed")
+            logging.fatal("Could not call install_name_tool -- you must have Apple's development tools installed")
             raise
 
 
-def _builtin_change_mach_o(maxint):
-    MH_MAGIC = 0xFEEDFACE
-    MH_CIGAM = 0xCEFAEDFE
-    MH_MAGIC_64 = 0xFEEDFACF
-    MH_CIGAM_64 = 0xCFFAEDFE
-    FAT_MAGIC = 0xCAFEBABE
-    BIG_ENDIAN = ">"
-    LITTLE_ENDIAN = "<"
-    LC_LOAD_DYLIB = 0xC
+def _builtin_change_mach_o(maxint):  # noqa: C901
+    MH_MAGIC = 0xFEEDFACE  # noqa: N806
+    MH_CIGAM = 0xCEFAEDFE  # noqa: N806
+    MH_MAGIC_64 = 0xFEEDFACF  # noqa: N806
+    MH_CIGAM_64 = 0xCFFAEDFE  # noqa: N806
+    FAT_MAGIC = 0xCAFEBABE  # noqa: N806
+    BIG_ENDIAN = ">"  # noqa: N806
+    LITTLE_ENDIAN = "<"  # noqa: N806
+    LC_LOAD_DYLIB = 0xC  # noqa: N806
 
     class FileView:
         """A proxy for file-like objects that exposes a given view of a file. Modified from macholib."""
 
-        def __init__(self, file_obj, start=0, size=maxint):
+        def __init__(self, file_obj, start=0, size=maxint) -> None:
             if isinstance(file_obj, FileView):
-                self._file_obj = file_obj._file_obj
+                self._file_obj = file_obj._file_obj  # noqa: SLF001
             else:
                 self._file_obj = file_obj
             self._start = start
             self._end = start + size
             self._pos = 0
 
-        def __repr__(self):
+        def __repr__(self) -> str:
             return f"<fileview [{self._start:d}, {self._end:d}] {self._file_obj!r}>"
 
         def tell(self):
@@ -248,7 +168,8 @@ def _builtin_change_mach_o(maxint):
             elif whence == os.SEEK_END:
                 seek_to += self._end
             else:
-                raise OSError(f"Invalid whence argument to seek: {whence!r}")
+                msg = f"Invalid whence argument to seek: {whence!r}"
+                raise OSError(msg)
             self._checkwindow(seek_to, "seek")
             self._file_obj.seek(seek_to)
             self._pos = seek_to - self._start
@@ -262,7 +183,7 @@ def _builtin_change_mach_o(maxint):
             self._pos += len(content)
 
         def read(self, size=maxint):
-            assert size >= 0
+            assert size >= 0  # noqa: S101
             here = self._start + self._pos
             self._checkwindow(here, "read")
             size = min(size, self._end - here)
@@ -278,15 +199,17 @@ def _builtin_change_mach_o(maxint):
             return res[0]
         return res
 
-    def mach_o_change(at_path, what, value):
-        """Replace a given name (what) in any LC_LOAD_DYLIB command found in the given binary with a new name (value),
-        provided it's shorter."""
+    def mach_o_change(at_path, what, value):  # noqa: C901
+        """
+        Replace a given name (what) in any LC_LOAD_DYLIB command found in the given binary with a new name (value),
+        provided it's shorter.
+        """  # noqa: D205
 
         def do_macho(file, bits, endian):
             # Read Mach-O header (the magic number is assumed read by the caller)
             cpu_type, cpu_sub_type, file_type, n_commands, size_of_commands, flags = read_data(file, endian, 6)
             # 64-bits header has one more field.
-            if bits == 64:
+            if bits == 64:  # noqa: PLR2004
                 read_data(file, endian)
             # The header is followed by n commands
             for _ in range(n_commands):
@@ -328,7 +251,7 @@ def _builtin_change_mach_o(maxint):
             elif magic == MH_CIGAM_64:
                 do_macho(file, 64, LITTLE_ENDIAN)
 
-        assert len(what) >= len(value)
+        assert len(what) >= len(value)  # noqa: S101
 
         with open(at_path, "r+b") as f:
             do_file(f)
@@ -336,8 +259,20 @@ def _builtin_change_mach_o(maxint):
     return mach_o_change
 
 
+class CPython3macOsBrew(CPython3, CPythonPosix):
+    @classmethod
+    def can_describe(cls, interpreter):
+        return is_macos_brew(interpreter) and super().can_describe(interpreter)
+
+    @classmethod
+    def setup_meta(cls, interpreter):  # noqa: ARG003
+        meta = BuiltinViaGlobalRefMeta()
+        meta.copy_error = "Brew disables copy creation: https://github.com/Homebrew/homebrew-core/issues/138159"
+        return meta
+
+
 __all__ = [
     "CPythonmacOsFramework",
-    "CPython2macOsFramework",
     "CPython3macOsFramework",
+    "CPython3macOsBrew",
 ]
