@@ -1,9 +1,10 @@
+from __future__ import annotations
+
 import abc
 from pathlib import Path
 
 from virtualenv.create.via_global_ref.builtin.ref import PathRefToDest, RefMust, RefWhen
-
-from ..via_global_self_do import ViaGlobalRefVirtualenvBuiltin
+from virtualenv.create.via_global_ref.builtin.via_global_self_do import ViaGlobalRefVirtualenvBuiltin
 
 
 class PyPy(ViaGlobalRefVirtualenvBuiltin, metaclass=abc.ABCMeta):
@@ -15,8 +16,7 @@ class PyPy(ViaGlobalRefVirtualenvBuiltin, metaclass=abc.ABCMeta):
     def _executables(cls, interpreter):
         host = Path(interpreter.system_executable)
         targets = sorted(f"{name}{PyPy.suffix}" for name in cls.exe_names(interpreter))
-        must = RefMust.COPY if interpreter.version_info.major == 2 else RefMust.NA
-        yield host, targets, must, RefWhen.ANY
+        yield host, targets, RefMust.NA, RefWhen.ANY
 
     @classmethod
     def executables(cls, interpreter):
