@@ -1,11 +1,14 @@
+from __future__ import annotations
+
 from abc import ABCMeta, abstractmethod
 
 
 class Seeder(metaclass=ABCMeta):
     """A seeder will install some seed packages into a virtual environment."""
 
-    def __init__(self, options, enabled):
+    def __init__(self, options, enabled) -> None:
         """
+        Create.
 
         :param options: the parsed options as defined within :meth:`add_parser_arguments`
         :param enabled: a flag weather the seeder is enabled or not
@@ -14,7 +17,7 @@ class Seeder(metaclass=ABCMeta):
         self.env = options.env
 
     @classmethod
-    def add_parser_arguments(cls, parser, interpreter, app_data):  # noqa: U100
+    def add_parser_arguments(cls, parser, interpreter, app_data):
         """
         Add CLI arguments for this seed mechanisms.
 
@@ -26,7 +29,8 @@ class Seeder(metaclass=ABCMeta):
 
     @abstractmethod
     def run(self, creator):
-        """Perform the seed operation.
+        """
+        Perform the seed operation.
 
         :param creator: the creator (based of :class:`virtualenv.create.creator.Creator`) we used to create this \
         virtual environment
